==> digikam-3.0.0.tar.bz2: digikam-3.0.0/extra/kipi-plugins/printimages/plugin/kipiplugin_printimages.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Print images
Name=Print images
Name[ast]=Imprentar imáxenes
Name[bg]=Отпечатване на изображения
Name[bs]=Štampaj slike
Name[ca]=Impressió d'imatges
Name[ca@valencia]=Impressió d'imatges
Name[cs]=Vytisknout obrázky
Name[da]=Udskriv billeder
Name[de]=Bilder drucken
Name[el]=Εκτύπωση εικόνων
Name[en_GB]=Print images
Name[es]=Imprimir imágenes
Name[et]=Piltide trükkimine
Name[eu]=Inprimatu irudiak
Name[fi]=Kuvien tulostus
Name[fr]=Impression d'images
Name[ga]=Priontáil íomhánna
Name[gl]=Imprimir imaxes
Name[hu]=Képek nyomtatása
Name[is]=Prenta myndir
Name[it]=Stampa immagini
Name[ja]=画像の印刷
Name[km]=បោះពុម្ព​រូបភាព
Name[lv]=Drukāt attēlus
Name[mai]=छवि छापू
Name[nb]=Bildeutskrift
Name[nds]=Biller drucken
Name[nl]=Afbeeldingen afdrukken
Name[pa]=ਚਿੱਤਰ ਪਰਿੰਟ ਕਰੋ
Name[pl]=Drukuj obrazy
Name[pt]=Imprimir as imagens
Name[pt_BR]=Imprimir imagens
Name[ro]=Tipărește imaginile
Name[ru]=Печать изображений
Name[sk]=Vytlačiť obrázky
Name[sl]=Natisni slike
Name[sq]=Printo imazhet
Name[sv]=Skriv ut bilder
Name[th]=พิมพ์ภาพต่าง ๆ
Name[tr]=Resimleri Yazdır
Name[ug]=سۈرەت باس
Name[uk]=Друк зображень
Name[x-test]=xxPrint imagesxx
Name[zh_CN]=打印图像
Name[zh_TW]=列印影像
Comment=A tool to print images in various formats
Comment[ast]=Una ferramienta pa imprentar imáxenes en dellos formatos
Comment[bg]=Инструмент за отпечатване на изображения в различни формати
Comment[bs]=Alat za štampanje slika u različitim formatima
Comment[ca]=Una eina per a imprimir imatges en diversos formats
Comment[ca@valencia]=Una eina per a imprimir imatges en diversos formats
Comment[cs]=Nástroj pro tisk obrázků v různých formátech
Comment[da]=Et værktøj til at udskrive billeder i forskellige formater
Comment[de]=Ein Werkzeug, um Bilder in verschiedenen Formaten zu drucken
Comment[el]=Εργαλείο εκτύπωσης εικόνων σε διάφορες μορφές
Comment[en_GB]=A tool to print images in various formats
Comment[es]=Una herramienta para imprimir imágenes en varios formatos
Comment[et]=Tööriist piltide trükkimiseks mitmesuguses suuruses
Comment[eu]=Irudiak hainbat formatutan inprimatzeko tresna
Comment[fi]=Kuvien tulostus eri muodoissa
Comment[fr]=Outil pour l'impression d'images dans différents formats
Comment[ga]=Uirlis a phriontálann íomhánna i bhformáidí éagsúla
Comment[gl]=Unha ferramenta para imprimir imaxes en distintos formatos
Comment[hu]=Egy eszköz képek különféle formátumokba történő nyomtatásához
Comment[is]=Verkfæri til að prenta myndir í ýmsum stærðum
Comment[it]=Uno strumento per stampare immagini in diversi formati
Comment[km]=ឧបករណ៍​ត្រូវ​បោះពុម្ព​រូបភាព​ជា​ទ្រង់ទ្រាយ​ផ្សេងៗ
Comment[lv]=Rīks attēlu drukāšanai dažādos formātos
Comment[nb]=Et verktøy for å skrive ut bilder i forskjellige formater
Comment[nds]=En Warktüüch, mit dat sik Biller in verscheden Formaten utdrucken laat
Comment[nl]=Een hulpmiddel om afbeeldingen af te drukken in verschillende formaten
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਕਈ ਫਾਰਮੈਟਾਂ ਵਿੱਚ ਪਰਿੰਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do drukowani obrazów w różnych formatach
Comment[pt]=Uma ferramenta para imprimir imagens em vários formatos
Comment[pt_BR]=Uma ferramenta para imprimir imagens em vários formatos
Comment[ro]=O unealtă de tipărit imagini în diverse formate
Comment[ru]=Инструмент для печати изображений в различных форматах
Comment[sk]=Nástroj na tlač obrázkov v rôznych formátoch
Comment[sl]=Orodje za tiskanje slik v različnih oblikah
Comment[sq]=Një mjet për të printuar imazhet në formate të ndryshme
Comment[sv]=Ett verktyg för att skriva ut bilder med diverse format
Comment[th]=เครื่องมือพิมพ์ภาพต่าง ๆ ที่มีรูปแบบหลากหลาย
Comment[tr]=Çeşitli biçimlerdeki resimleri yazdırmak için bir araç
Comment[uk]=Інструмент для друку зображень у різних форматах
Comment[x-test]=xxA tool to print images in various formatsxx
Comment[zh_CN]=一个以多种格式打印图像的工具
Comment[zh_TW]=用各種格式列印影像的工具
Type=Service
Icon=document-print
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_printimages
X-KIPI-MergeMenu=true
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Angelo Naselli, anaselli@linux.it

==> digikam-4.4.0.tar.bz2: digikam-4.4.0/extra/kipi-plugins/printimages/plugin/kipiplugin_printimages.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Print images
Name=Print images
Name[ast]=Imprentar imáxenes
Name[bg]=Отпечатване на изображения
Name[bs]=Štampaj slike
Name[ca]=Impressió d'imatges
Name[ca@valencia]=Impressió d'imatges
Name[cs]=Vytisknout obrázky
Name[da]=Udskriv billeder
Name[de]=Bilder drucken
Name[el]=Εκτύπωση εικόνων
Name[en_GB]=Print images
Name[es]=Imprimir imágenes
Name[et]=Piltide trükkimine
Name[eu]=Inprimatu irudiak
Name[fi]=Kuvien tulostus
Name[fr]=Imprimer des images
Name[ga]=Priontáil íomhánna
Name[gl]=Imprimir imaxes
Name[hu]=Képek nyomtatása
Name[is]=Prenta myndir
Name[it]=Stampa immagini
Name[ja]=画像の印刷
Name[km]=បោះពុម្ព​រូបភាព
Name[lt]=Spausdinti paveikslėlius
Name[lv]=Drukāt attēlus
Name[mai]=छवि छापू
Name[mr]=प्रतिमा छापा
Name[nb]=Bildeutskrift
Name[nds]=Biller drucken
Name[nl]=Afbeeldingen afdrukken
Name[pa]=ਚਿੱਤਰ ਪਰਿੰਟ ਕਰੋ
Name[pl]=Drukuj obrazy
Name[pt]=Imprimir as imagens
Name[pt_BR]=Imprimir imagens
Name[ro]=Tipărește imaginile
Name[ru]=Печать изображений
Name[sk]=Vytlačiť obrázky
Name[sl]=Natisni slike
Name[sq]=Printo imazhet
Name[sv]=Skriv ut bilder
Name[th]=พิมพ์ภาพต่าง ๆ
Name[tr]=Resimleri Yazdır
Name[ug]=سۈرەت باس
Name[uk]=Друк зображень
Name[x-test]=xxPrint imagesxx
Name[zh_CN]=打印图像
Name[zh_TW]=列印影像
Comment=A tool to print images in various formats
Comment[ast]=Una ferramienta pa imprentar imáxenes en dellos formatos
Comment[bg]=Инструмент за отпечатване на изображения в различни формати
Comment[bs]=Alat za štampanje slika u različitim formatima
Comment[ca]=Una eina per a imprimir imatges en diversos formats
Comment[ca@valencia]=Una eina per a imprimir imatges en diversos formats
Comment[cs]=Nástroj pro tisk obrázků v různých formátech
Comment[da]=Et værktøj til at udskrive billeder i forskellige formater
Comment[de]=Ein Werkzeug, um Bilder in verschiedenen Formaten zu drucken
Comment[el]=Εργαλείο εκτύπωσης εικόνων σε διάφορες μορφές
Comment[en_GB]=A tool to print images in various formats
Comment[es]=Una herramienta para imprimir imágenes en varios formatos
Comment[et]=Tööriist piltide trükkimiseks mitmesuguses suuruses
Comment[eu]=Irudiak hainbat formatutan inprimatzeko tresna
Comment[fi]=Kuvien tulostus eri muodoissa
Comment[fr]=Un outil d'impression d'images dans différents formats
Comment[ga]=Uirlis a phriontálann íomhánna i bhformáidí éagsúla
Comment[gl]=Unha ferramenta para imprimir imaxes en distintos formatos
Comment[hu]=Egy eszköz képek különféle formátumokba történő nyomtatásához
Comment[is]=Verkfæri til að prenta myndir í ýmsum stærðum
Comment[it]=Uno strumento per stampare immagini in diversi formati
Comment[km]=ឧបករណ៍​ត្រូវ​បោះពុម្ព​រូបភាព​ជា​ទ្រង់ទ្រាយ​ផ្សេងៗ
Comment[lv]=Rīks attēlu drukāšanai dažādos formātos
Comment[nb]=Et verktøy for å skrive ut bilder i forskjellige formater
Comment[nds]=En Warktüüch, mit dat sik Biller in verscheden Formaten utdrucken laat
Comment[nl]=Een hulpmiddel om afbeeldingen af te drukken in verschillende formaten
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਕਈ ਫਾਰਮੈਟਾਂ ਵਿੱਚ ਪਰਿੰਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do drukowani obrazów w różnych formatach
Comment[pt]=Uma ferramenta para imprimir imagens em vários formatos
Comment[pt_BR]=Uma ferramenta para imprimir imagens em vários formatos
Comment[ro]=O unealtă de tipărit imagini în diverse formate
Comment[ru]=Инструмент для печати изображений в различных форматах
Comment[sk]=Nástroj na tlač obrázkov v rôznych formátoch
Comment[sl]=Orodje za tiskanje slik v različnih oblikah
Comment[sq]=Një mjet për të printuar imazhet në formate të ndryshme
Comment[sv]=Ett verktyg för att skriva ut bilder med diverse format
Comment[th]=เครื่องมือพิมพ์ภาพต่าง ๆ ที่มีรูปแบบหลากหลาย
Comment[tr]=Çeşitli biçimlerdeki resimleri yazdırmak için bir araç
Comment[uk]=Інструмент для друку зображень у різних форматах
Comment[x-test]=xxA tool to print images in various formatsxx
Comment[zh_CN]=一个以多种格式打印图像的工具
Comment[zh_TW]=用各種格式列印影像的工具
Type=Service
Icon=document-print
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_printimages
X-KIPI-MergeMenu=true
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Angelo Naselli, anaselli at linux dot it
